@@ -26,7 +26,7 @@ class CloudStorageGenerator(GCPGenerator):
         ),
     )
 
-    def _update_data(self, row):  # pylint: disable=arguments-differ
+    def _update_data(self, row):
         """Update a data row with storage values."""
         if self.attributes:
             row["Line Item"] = self.attributes["Line Item"]
@@ -43,9 +43,9 @@ class CloudStorageGenerator(GCPGenerator):
             storage = choice(self.STORAGE)
             row["Line Item"] = storage[0]
             row["Measurement1"] = storage[0]
-            row["Measurement1 Total Consumption"] = self.fake.pyint()  # pylint: disable=maybe-no-member
+            row["Measurement1 Total Consumption"] = self.fake.pyint()
             row["Measurement1 Units"] = storage[1]
-            row["Cost"] = self.fake.pyint()  # pylint: disable=maybe-no-member
+            row["Cost"] = self.fake.pyint()
             row["Currency"] = "USD"
             row["Description"] = storage[2]
         return row
@@ -56,7 +56,7 @@ class CloudStorageGenerator(GCPGenerator):
         data = {}
         for day in days:
             rows = []
-            for _ in range(0, self.num_instances):
+            for _ in range(self.num_instances):
                 row = self._init_data_row(day["start"], day["end"])
                 row = self._update_data(row)
                 rows.append(row)
